==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Plugin/Derivative/MWMigrateEntityReferenceRevisions.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\Derivative;

use Drupal\migrate_wizard\Plugin\migrate\destination\MWEntityReferenceRevisions;
use Drupal\migrate\Plugin\Derivative\MigrateEntityRevision;

/**
 * Class MWMigrateEntityReferenceRevisions
 */
class MWMigrateEntityReferenceRevisions extends MigrateEntityRevision  {

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($basePluginDefinition) {
    foreach ($this->entityDefinitions as $entityType => $entityInfo) {
      if ($entityInfo->getKey('revision')) {
        $this->derivatives[$entityType] = [
          'id' => "entity_reference_revisions:$entityType",
          'class' => MWEntityReferenceRevisions::class,
          'requirements_met' => 1,
          'provider' => $entityInfo->getProvider(),
        ];
      }
    }
    return $this->derivatives;
  }

}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Plugin/Derivative/MWMigrateEntityReferenceRevisions.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\Derivative;

use Drupal\migrate\Plugin\Derivative\MigrateEntityRevision;
use Drupal\migrate_wizard\Plugin\migrate\destination\MWEntityReferenceRevisions;

/**
 * Class MWMigrateEntityReferenceRevisions.
 */
class MWMigrateEntityReferenceRevisions extends MigrateEntityRevision {

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($basePluginDefinition) {
    foreach ($this->entityDefinitions as $entityType => $entityInfo) {
      if ($entityInfo->getKey('revision')) {
        $this->derivatives[$entityType] = [
          'id' => "entity_reference_revisions:{$entityType}",
          'class' => MWEntityReferenceRevisions::class,
          'requirements_met' => 1,
          'provider' => $entityInfo->getProvider(),
        ];
      }
    }

    return $this->derivatives;
  }

}
